@@ -977,6 +977,9 @@ class StandardFunction:
         """
         assert direction in ["x", "y"]
 
+        if point_coord is None or origin_coord is None or angle is None:
+            return None
+
         point_shifted = point_coord - origin_coord
 
         # point_rotated_x = point_shifted[:, 0] * np.cos(angle.T) + point_shifted[:, 1] * np.sin(angle.T)
@@ -1556,8 +1559,8 @@ class StandardFunction:
         return vc
 
     @staticmethod
-    def nij(force_x: pint.Quantity, force_z: pint.Quantity, moment_y: pint.Quantity, distance_occipital_condyle: float,
-            nij_fzc_te: float, nij_fzc_co: float, nij_myc_fl: float, nij_myc_ex: float):
+    def nij(force_x: pint.Quantity, force_z: pint.Quantity, moment_y: pint.Quantity, distance_occipital_condyle: pint.Quantity,
+            nij_fzc_te: pint.Quantity, nij_fzc_co: pint.Quantity, nij_myc_fl: pint.Quantity, nij_myc_ex: pint.Quantity):
         """
 
         Args:
@@ -1581,11 +1584,11 @@ class StandardFunction:
         force_z = force_z.to_base_units()
         moment_y = moment_y.to_base_units()
 
-        moc_d = distance_occipital_condyle  # m
-        nij_fzc_te = nij_fzc_te  # N
-        nij_fzc_co = nij_fzc_co  # N
-        nij_myc_fl = nij_myc_fl  # Nm
-        nij_myc_ex = nij_myc_ex  # Nm
+        moc_d = distance_occipital_condyle.to_base_units()  # m
+        nij_fzc_te = nij_fzc_te.to_base_units()  # N
+        nij_fzc_co = nij_fzc_co.to_base_units()  # N
+        nij_myc_fl = nij_myc_fl.to_base_units()  # Nm
+        nij_myc_ex = nij_myc_ex.to_base_units()  # Nm
 
         nij = np.zeros(shape=(len(force_z)))
         temp_n_value = np.zeros(shape=(4,))
@@ -1719,4 +1722,4 @@ class StandardFunction:
         """
         assert np.any(contact_force)
         index = np.where(contact_force != 0)
-        return vel[np.argmin(np.abs(time_nodout.to_base_units() - time_rcf.to_base_units()[index][0])) - 1]
\ No newline at end of file
+        return vel[np.argmin(np.abs(time_nodout.to_base_units() - time_rcf.to_base_units()[index][0])) - 1]
