@@ -290,9 +290,12 @@ class BinoutData(object):
 
             # type_data = np.reshape(type_data, (time_interp.shape[0], -1))
             data_interp = np.zeros(shape=(self._time_interp.shape[0], type_data.shape[1]))
+
             for i in range(type_data.shape[1]):
+                data_to_consider = min(self._time_interp.shape[0], len(type_data[:, i]))
                 data_interp[:, i] = np.interp(self._time_interp.magnitude,
-                                              self._time.magnitude[:self._time_interp.shape[0]], type_data[:, i])
+                                              self._time.magnitude[:data_to_consider],
+                                              type_data[:data_to_consider, i])
             data[key] = data_interp
 
         self._data = {**self._data, **data}
@@ -480,7 +483,7 @@ class BinoutData(object):
         r_velocity = angle/t
         r_acceleration = angle/(t**2)
 
-        if "forc" in channel_name or "axial" in channel_name or "radial" in channel_name:
+        if "forc" in channel_name or "axial" in channel_name or "radial" in channel_name or "shear" in channel_name:
             return force
 
         elif "moment" in channel_name:
