@@ -127,6 +127,16 @@ class DynasaurDefinitions:
         self._data_vis = {}
         self._units = Units()
 
+    def get_unit_dimension_from_unit(self, unit):
+        """
+
+        :param unit:
+        :return:
+        """
+        ureg = self._units.ureg
+        return ureg(unit)
+
+
     def get_param_dict_from_command(self, command):
         """
 
@@ -146,7 +156,7 @@ class DynasaurDefinitions:
             d[PluginsParamDictDef.DYNASAUR_JSON] = self.get_criteria(command['criteria'])
             return d
         else:
-            print("[ERROR] Command not in command list")
+            self._logger.emit(LOGConstants.ERROR[0], "Command not in command list")
             return
 
     def get_units(self):
@@ -168,7 +178,6 @@ class DynasaurDefinitions:
         """
         if key not in self._criteria.keys() or len(self._criteria) == 0:
             self._logger.emit(LOGConstants.ERROR[0], LoggerERROR.print_statements[6] + "\"" + key + "\"")
-            exit("Exiting, check your def file")
             return
         return self._criteria[key]
 
@@ -215,7 +224,6 @@ class DynasaurDefinitions:
         """
         if key not in self._data_vis.keys() or len(self._data_vis) == 0:
             self._logger.emit(LOGConstants.ERROR[0], LoggerERROR.print_statements[7] + "\"" + key + "\"")
-            exit("Exiting, check your def file")
         return self._data_vis[key]
 
     def get_object_ids_from_object_name(self, object_name, data_container_name):
@@ -337,12 +345,14 @@ class DynasaurDefinitions:
 
         """
         ls = []
+        d = {}
         if DefinitionConstants.CRITERIA == plugin_name:
-            self.get_all_data_types_from_json(self._criteria, ls)
+            d = self._criteria
         elif DefinitionConstants.DATA_VIS == plugin_name:
-            self.get_all_data_types_from_json(self._data_vis, ls)
-        else:
-            assert False
+            d = self._data_vis
+
+        self.get_all_data_types_from_json(d, ls)
+
         return ls
 
     def get_parts_by_object_containing_part_ids(self, tmp_object, part_ids):
@@ -565,7 +575,8 @@ class DynasaurDefinitions:
 
         """
         if fn is None:
-            exit("No definition file")
+            self._logger.emit(LOGConstants.ERROR[0], "No definition file")
+            return
 
         if isinstance(fn, str):
             fn = [fn]
@@ -573,7 +584,8 @@ class DynasaurDefinitions:
         if isinstance(fn, list):
 
             if len(fn) < 1:
-                exit("No definition file(s) in list")
+                self._logger.emit(LOGConstants.ERROR[0], "No definition file(s) in list")
+                return
             is_entity_set = {i: False for i in DefinitionConstants.__dict__ if i[:1] != "_"}
 
             for single_def_file in fn:
@@ -589,7 +601,7 @@ class DynasaurDefinitions:
                                         is_entity_set[DefinitionConstants.TITLE] = True
                                     else:
                                         self._logger.emit(LOGConstants.ERROR[0], LoggerERROR.print_statements[8] + DefinitionConstants.TITLE)
-                                        exit("Entity Title already set " + self._title)
+                                        return
 
                                 elif DefinitionConstants.UNIT in j_object:
                                     if not is_entity_set[DefinitionConstants.UNIT]:
@@ -597,7 +609,7 @@ class DynasaurDefinitions:
                                         is_entity_set[DefinitionConstants.UNIT] = True
                                     else:
                                         self._logger.emit(LOGConstants.ERROR[0], LoggerERROR.print_statements[8] + DefinitionConstants.UNIT)
-                                        exit("Entity Units already set")
+                                        return
 
                                 elif DefinitionConstants.CRITERIA in j_object:
                                     self._set_criteria(j_object)
@@ -619,14 +631,15 @@ class DynasaurDefinitions:
 
                         except ValueError as e:
                             self._logger.emit(LOGConstants.ERROR[0], LoggerERROR.print_statements[4] % e)
-                            exit("Exiting - Invalid JSON file")  # Because Mutant, if GUI "exit()" comment
+                            self._logger.emit(LOGConstants.ERROR[0], "Invalid JSON file")
                             return
                 except FileNotFoundError as e:
                     self._logger.emit(LOGConstants.ERROR[0],  e.strerror + " " + e.filename)
-                    exit(e.strerror + " " + e.filename)
+                    return
 
         else:
-            exit("No definition file")
+            self._logger.emit(LOGConstants.ERROR[0], "No definition file")
+            return
 
         self._logger.emit(LOGConstants.READ_DYNASAUR_DEF[0], LD.DONE)
 
