@@ -6,6 +6,7 @@ import csv
 from datetime import datetime
 
 from lasso.dyna.Binout import Binout
+from pint import UnitRegistry
 
 from ..utils.constants import StandardFunctionsDefinition, JsonConstants, ObjectConstantsForData, \
     LoggerERROR, LoggerWARNING
@@ -63,6 +64,17 @@ class Plugin(object):
         self._timestamp = datetime.today().strftime("%Y-%m-%d-%H-%M-%S")
         self._units = self._dynasaur_definitions.get_units()
         self._data_requirements = self._dynasaur_definitions.get_required_datatypes(name)
+        # check for subset
+
+        dynasaur_data_types = [ObjectConstantsForData.__dict__[i] for i in ObjectConstantsForData.__dict__ if not i.startswith("__")]
+        req_in_ddt = [req not in dynasaur_data_types for req in self._data_requirements]
+
+        if len(np.array(self._data_requirements)[req_in_ddt]) != 0:
+            self._logger.emit(LOGConstants.ERROR[0], "Your calculation_procedure_def_file contains a data type which is"
+                                                     + " not understood : "
+                                                     + ", ".join(np.array(self._data_requirements)[req_in_ddt])
+                                                     + "  \nAvailable types are : \n" + "\n".join(dynasaur_data_types))
+
         self._data = None
         self._name = name
         self._sample_types = []
@@ -98,7 +110,7 @@ class Plugin(object):
         kwargs = {}
         for key in param_dict:
             kwargs[key] = param_dict[key]
-        #kwargs["units"] = units
+
         return kwargs
 
     def _call_standard_function(self, function_name, param_dict):
@@ -161,7 +173,9 @@ class Plugin(object):
                 self._logger.emit(LOGConstants.ERROR[0], "Calculation of " + function_name + " aborted!")
 
         elif JsonConstants.VALUE in json_object.keys():
-            return np.array(json_object[JsonConstants.VALUE]) * self._dynasaur_definitions.get_units().dimensionless
+            # return np.array(json_object[JsonConstants.VALUE]) * json_object[JsonConstants.UNIT]
+            return np.array(json_object[JsonConstants.VALUE]) * \
+                   self._dynasaur_definitions.get_unit_dimension_from_unit(json_object[JsonConstants.UNIT])
 
         elif JsonConstants.TYPE in json_object.keys():
             data_type = json_object[JsonConstants.TYPE]
